# Variational Mesh
[![license](https://img.shields.io/badge/license-APACHE2-green)](https://www.apache.org/licenses/LICENSE-2.0)
[![language](https://img.shields.io/badge/language-Python3-blue)](https://www.python.org/)
[![DOI](https://zenodo.org/badge/315695302.svg)](https://zenodo.org/badge/latestdoi/315695302)

A variational mesh implementation to optimize meshes for quantum chemistry calculations with [PySCF](https://github.com/pyscf/pyscf) or [PyFLOSIC](https://github.com/pyflosic/pyflosic).

## Documentation

To learn how the implementation works or how to use it, take a look inside the [documentation](https://wangenau.gitlab.io/variational_mesh/).

## Installation

The package can be installed using pip

```
pip install var-mesh
```

## Authors

* **Wanja Schulze** - Maintainer - wangenau@protonmail.com
* **Jens Kortus** - Supervisor
* **Sebastian Schwalbe** - Co-worker - theonov13@gmail.com
* **Jakob Kraus** - Co-worker - jakob.kraus@physik.tu-freiberg.de
* **Kai Trepte** - Co-worker - kai.trepte1987@gmail.com
* **Simon Liebing** - Co-worker

## License

This project is licensed under the Apache 2.0 License - see the [LICENSE](LICENSE) file for details.
